/**
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.deephacks.tools4j.config.test;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * This annotation is to be set on classes that handle junit test setup
 * (such as @Before, @BeforeClass, @After) for a specific implementation
 * of an interface. 
 * 
 * Test suite builders use this annotation to automatically invoke these 
 * test setup classes when this specific implementation is targeted for test.
 * 
 * This relieves users from knowing how to do test setup and teardown for
 * specific implementations.
 * 
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface TestSetupTeardown {

    /**
     * @return the service interface that the implementation implements.
     */
    Class<?> value();
}
